@@ -262,7 +262,7 @@ class BaseDatabaseOperations(object):
 
     def prepare_sql_script(self, sql):
         """
-        Takes a SQL script that may contain multiple lines and returns a list
+        Takes an SQL script that may contain multiple lines and returns a list
         of statements to feed to successive cursor.execute() calls.
 
         Since few databases are able to process raw SQL scripts in a single
@@ -374,7 +374,7 @@ class BaseDatabaseOperations(object):
         to tables with foreign keys pointing the tables being truncated.
         PostgreSQL requires a cascade even if these tables are empty.
         """
-        raise NotImplementedError('subclasses of BaseDatabaseOperations must provide a sql_flush() method')
+        raise NotImplementedError('subclasses of BaseDatabaseOperations must provide an sql_flush() method')
 
     def sequence_reset_by_name_sql(self, style, sequences):
         """
